""" Library entry point """
import re, requests
from bs4 import BeautifulSoup


class YoutubeScrape(object):
    """ Scraper object to hold data """

    def __init__(self, soup):
        """ Initialize and scrape """
        self.soup = soup
        try:
            self.title = self.parse_string(".watch-title")
        except:
            self.title = self.parse_string(".title")
        try:
            self.poster = self.parse_string(".yt-user-info")
        except:
            self.poster = self.parse_string(".ytd-channel-name")
        try:
            self.views = self.parse_int(".watch-view-count")
        except:
            self.views = self.parse_int(".view-count")
        try:
            self.published = self.parse_string(".watch-time-text")
        except:
            self.published = self.parse_string("#date")
        self.published = re.sub(r"(Published|Uploaded) on", "", self.published).strip()
        try:
            self.like = self.parse_int(".yt-uix-clickcard", 4)
        except:
            pass
        try:
            self.dislike = self.parse_int(".yt-uix-clickcard", 5)
        except:
            pass

    def parse_int(self, selector, pos=0):
        """ Extract one integer element from soup """
        return int(re.sub("[^0-9]", "", self.parse_string(selector, pos)))

    def parse_string(self, selector, pos=0):
        """ Extract one particular element from soup """
        return self.soup.select(selector)[pos].get_text().strip()


def scrape_html(html):
    """ Return meta information about a video """
    return YoutubeScrape(BeautifulSoup(html, "html.parser"))


def scrape_url(url):
    """ Scrape a given url for youtube information """

    # set English as scraping language
    headers = {"Accept-Language": "en-US,en;q=0.5"}
    html = requests.get(url, headers=headers).text
    return scrape_html(html)



import unittest
from youtube_scraper.scraper import scrape_html, scrape_url

TEST_DATA = '<html>\
    <span id="eow-title" class="watch-title " dir="ltr" title="thetitle">\
thetitle\
    </span>\
    <div class="yt-user-info">\
      <a href="/channel/asdkjasdkjashdkaljsdhasl" class=" yt-uix-sessionlink     spf-link  g-hovercard" data-name="" data-ytid="askdjahsdkaljshdaskasljd" data-sessionlink="asdasdjasdahsdjaksdllsjjs">theposter</a>\
    </div>\
    <div class="watch-view-count">9,999</div>\
    <strong class="watch-time-text">Published on Apr 1, 2013</strong>\
    <button class="yt-uix-button yt-uix-button-size-default yt-uix-button-opacity yt-uix-button-has-icon no-icon-markup like-button-renderer-like-button-unclicked  yt-uix-post-anchor yt-uix-tooltip" type="button" onclick=";return false;" aria-label="like this video along with 168 other people" title="I like this" id="watch-like" data-position="bottomright" data-post-action="/watch_actions_ajax?action_like_video=1&amp;video_id=7dlcxXxDGUI" data-force-position="true" data-orientation="vertical" data-post-data="" data-tooltip-text="I like this"><span class="yt-uix-button-content">168</span></button>\
    <button class="yt-uix-button yt-uix-button-size-default yt-uix-button-opacity yt-uix-button-has-icon no-icon-markup like-button-renderer-dislike-button-unclicked  yt-uix-post-anchor yt-uix-tooltip" type="button" onclick=";return false;" aria-label="dislike this video along with 8 other people" title="I dislike this" id="watch-dislike" data-position="bottomright" data-post-action="/watch_actions_ajax?action_dislike_video=1&amp;video_id=7dlcxXxDGUI" data-force-position="true" data-orientation="vertical" data-post-data="" data-tooltip-text="I dislike this"><span class="yt-uix-button-content">8</span></button>\
</html>'

class TestScraper(unittest.TestCase):
    def test_scrape_html(self):
        data = scrape_html(TEST_DATA)
        self.assertEqual(data.title, 'thetitle')
        self.assertEqual(data.poster, 'theposter')
        self.assertEqual(data.views, 9999)
        self.assertEqual(data.published, 'Apr 1, 2013')
        self.assertEqual(data.like, 168)
        self.assertEqual(data.dislike, 8)

    def test_scrape_url(self):
        data = scrape_url('http://youtube.com/watch?v=7dlcxXxDGUI')
        self.assertEqual(data.poster, 'TheViperAOC')

if __name__ == '__main':
    unittest.main()



from setuptools import setup, find_packages


setup(
    name="youtube-scraper",
    version="1.0.3",
    description=("Provide information for youtube related metadata"),
    classifiers=[
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords="youtube scraper meta",
    author="Jon Robison",
    author_email="narfman0@gmail.com",
    url="https://github.com/narfman0/youtube-scraper",
    license="LICENSE",
    packages=find_packages(),
    include_package_data=True,
    py_modules=["youtube_scraper.scraper"],
    zip_safe=True,
    install_requires=["beautifulsoup4", "requests"],
    test_suite="tests",
)
